---
name: Bug Report
about: Write a report to help us improve

---

**Describe the bug**

A clear and concise description of what the bug is, in particular:

- What did you do?
- What actually happened?
- What did you expect to happen?

**Failing Test**

Please put code (ideally in the form of a unit test) which fails below

**Screenshots**

If applicable, add screenshots to help explain your problem.

**System (please complete the following information):**

 - OS: [e.g. Windows, Linux, macOS]
 - Python and openscm commit/version [e.g. Python 3.5]

**Additional context**

Add any other context about the problem here.
